==> sivel-1.0.4.tgz: users/sivel/bin/mueve.sh <==
#!/bin/sh
# Mueve SIVeL a otro URL y otra base de datos
# Dominio pblico. 2010. Sin garantas. vtamara@pasosdeJesus.org

dirdest=$1;
nuevonombd=$2;
if (test "$dirdest" = "") then {
	dirdest="/var/www/htdocs/sivel10";
} fi;
if (test "$nuevonombd" = "") then {
	nuevonombd="sivel10";
} fi;

if (test ! -f vardb.sh -o ! -f confv.php) then {
	echo "*** Ejecute desde el directorio con fuentes de SIVeL 1.0";
	exit 1;
} fi;
. ./vardb.sh

dirac=`pwd`;

dpl=`stat -f "%Su" confv.php`
if (test "$USER" != "$dpl") then {
	echo "*** El usuario que ejecuta debera ser el dueo de las fuentes de $dirac y tener permiso para ejecutar sudo";
	exit 1;
} fi;

gdpl=`stat -f "%Sg" confv.php`

echo "Respaldando base en $rlocal/movido-$nommes.gz";
bin/pgdump.sh
if (test "$?" != "0") then {
	echo "*** Volcado de la base $dbnombre no pudo realizarse";
	exit 1;
} fi;
sudo cp $rlocal/$nommes.gz $rlocal/movido-$nommes.gz

echo "Respaldando fuentes en $rlocal/fuentes10-$dbnombre.tar.gz";
tar cfz $rlocal/fuentes10-$dbnombre.tar.gz $dirac

echo "Seguro que desea mover las fuentes de SIVeL 1.0 del directorio $dirac al directorio $dirdest y copiar los datos de la base $dbnombre del usuario $dbusuario a la base $nuevonombd del mismo usuario? (Cancele con Control-C o contine con ENTER)";
read

sudo mkdir -p $dirdest 2> /dev/null
if (test "$?" != "0") then {
	echo "*** No pudo crearse directorio destino $dirdest";
	exit 1;
} fi;
sudo chown $dpl:$gdpl $dirdest

cmd="(cd $dirdest; tar xvfz $rlocal/fuentes10-$dbnombre.tar.gz)";
eval $cmd;
if (test "$?" != "0") then {
	echo $cmd;
	echo "*** No pudo sacarse copia del directorio actual a $dirdest";
	exit 1;
} fi;

schlac=`echo $dirac | sed -e "s/\/var\/www//g"`
schlace=`echo $schlac | sed -e "s/\//\\\\\\\\\//g"`
schln=`echo $dirdest | sed -e "s/\/var\/www//g"`
schlne=`echo $schln | sed -e "s/\//\\\\\\\\\//g"`
dirace=`echo $dirac | sed -e "s/\//\\\\\\\\\//g"`
dirdeste=`echo $dirdest | sed -e "s/\//\\\\\\\\\//g"`

# Cambiar nombre base
e=0;
cp aut/conf.php $dirdest/aut/conf.php-antesmueve
e=`expr $e + $?`
cp DataObject.ini $dirdest/DataObject.ini-antesmueve
e=`expr $e + $?`
cp vardb.sh $dirdest/vardb.sh-antesmueve
e=`expr $e + $?`

sed -e "s/dbnombre *=.*;/dbnombre=\"$nuevonombd\";/g" aut/conf.php > $dirdest/aut/conf.php
e=`expr $e + $?`
sed -e "s/\(pgsql:.*\)$dbnombre\"$/\1$nuevonombd\"/g;s/=$schlace/=$schlne/g" DataObject.ini > $dirdest/DataObject.ini;
e=`expr $e + $?`
sed -e "s/$dirace/$dirdeste/g" vardb.sh > $dirdest/vardb.sh
e=`expr $e + $?`

if (test "$e" != "0") then {
	echo "No pudieron modificarse archivos";
	exit 1;
} fi;

cd $dirdest

ln -s sivel.ini $nuevonombd.ini 
ln -s sivel.links.ini $nuevonombd.links.ini

./conf.sh -i
# Crear base 
SIN_ESQUEMA=1 bin/creapg.sh
bin/restaura.sh $rlocal/movido-$nommes.gz

# Cambiar URL
sudo cp /var/www/conf/httpd.conf /var/www/conf/httpd.conf-antesmueve
grep "Alias.*$nuevonombd.*$dirdest" /var/www/conf/httpd.conf 
if (test "$?" != "0") then {
	sudo awk "/Alias.*icons/ { if (agregado != 1) { print \"Alias /$nuevonombd/ \\\"$dirdest/\\\"\"; } agregado=1; } /.*/ { print \$0; }" /var/www/conf/httpd.conf-antesmueve > /tmp/httpd-mueve
	if (test  "$?" != "0") then {
		echo "No pudo agregarse Alias en servidor Apache";
		exit 1;
	} fi;
	sudo cp /tmp/httpd-mueve /var/www/conf/httpd.conf
	sudo apachectl stop
	sleep 1
	sudo sh /etc/rc.local
	echo "";
} fi;

# Comprobar que funciona
grep "^ *FORCE_SSL_PROMPT:yes" /etc/lynx.cfg > /dev/null 2>&1
if (test "$?" != "0") then {
	sudo cp /etc/lynx.cfg /etc/lynx.cfg-antesmueve
	sudo sed -e "s/#* *FORCE_SSL_PROMPT.*/FORCE_SSL_PROMPT:yes/g" /etc/lynx.cfg-antesmueve > /tmp/lynx.cfg-mueve
	sudo cp /tmp/lynx.cfg-mueve /etc/lynx.cfg
} fi;
lynx -dump https://127.0.0.1/$nuevonombd/ > /tmp/dump-mueve
grep "Autenticacin" /tmp/dump-mueve > /dev/null 2>&1
if (test "$?" != "0") then {
	echo "La comprobacin de funcionamiento del nuevo URL fall";
	exit 1;
} fi;

echo "Con un navegador verifique sus datos en https://127.0.0.1/$nuevonombd/";
echo "Si desea borrar las fuentes de su localizacin inicial presione la letra 's'";
read sn
if (test "$sn" = "s") then {
	# Eliminar fuentes anteriores
	sudo pkg_delete sivel
	sudo pkg_delete partial-sivel
	sudo rm -rf $dirac
} fi;

==> sivel-1.0.5.tgz: users/sivel/bin/mueve.sh <==
#!/bin/sh
# Mueve SIVeL a otro URL y otra base de datos
# Dominio pblico. 2010. Sin garantas. vtamara@pasosdeJesus.org

dirdest=$1;
nuevonombd=$2;
if (test "$dirdest" = "") then {
	dirdest="/var/www/htdocs/sivel10";
} fi;
if (test "$nuevonombd" = "") then {
	nuevonombd="sivel10";
} fi;

if (test ! -f vardb.sh -o ! -f confv.php) then {
	echo "*** Ejecute desde el directorio con fuentes de SIVeL 1.0";
	exit 1;
} fi;
. ./vardb.sh

dirac=`pwd`;

dpl=`stat -f "%Su" confv.php`
if (test "$USER" != "$dpl") then {
	echo "*** El usuario que ejecuta debera ser el dueo de las fuentes de $dirac y tener permiso para ejecutar sudo";
	exit 1;
} fi;

gdpl=`stat -f "%Sg" confv.php`

echo "Respaldando base en $rlocal/movido-$nommes.gz";
bin/pgdump.sh
if (test "$?" != "0") then {
	echo "*** Volcado de la base $dbnombre no pudo realizarse";
	exit 1;
} fi;
sudo cp $rlocal/$nommes.gz $rlocal/movido-$nommes.gz

echo "Respaldando fuentes en $rlocal/fuentes10-$dbnombre.tar.gz";
tar cfz $rlocal/fuentes10-$dbnombre.tar.gz .

echo "Seguro que desea mover las fuentes de SIVeL 1.0 del directorio $dirac al directorio $dirdest y copiar los datos de la base $dbnombre del usuario $dbusuario a la base $nuevonombd del mismo usuario? (Cancele con Control-C o contine con ENTER)";
read

sudo mkdir -p $dirdest 2> /dev/null
if (test "$?" != "0") then {
	echo "*** No pudo crearse directorio destino $dirdest";
	exit 1;
} fi;
sudo chown $dpl:$gdpl $dirdest

cmd="(cd $dirdest; tar xvfz $rlocal/fuentes10-$dbnombre.tar.gz)";
eval $cmd;
if (test "$?" != "0") then {
	echo $cmd;
	echo "*** No pudo sacarse copia del directorio actual a $dirdest";
	exit 1;
} fi;

schlac=`echo $dirac | sed -e "s/\/var\/www//g"`
schlace=`echo $schlac | sed -e "s/\//\\\\\\\\\//g"`
schln=`echo $dirdest | sed -e "s/\/var\/www//g"`
schlne=`echo $schln | sed -e "s/\//\\\\\\\\\//g"`
dirace=`echo $dirac | sed -e "s/\//\\\\\\\\\//g"`
dirdeste=`echo $dirdest | sed -e "s/\//\\\\\\\\\//g"`

# Cambiar nombre base
e=0;
cp aut/conf.php $dirdest/aut/conf.php-antesmueve
e=`expr $e + $?`
cp DataObject.ini $dirdest/DataObject.ini-antesmueve
e=`expr $e + $?`
cp vardb.sh $dirdest/vardb.sh-antesmueve
e=`expr $e + $?`

sed -e "s/dbnombre *=.*;/dbnombre=\"$nuevonombd\";/g" aut/conf.php > $dirdest/aut/conf.php
e=`expr $e + $?`
sed -e "s/\(pgsql:.*\)$dbnombre\"$/\1$nuevonombd\"/g;s/=$schlace/=$schlne/g" DataObject.ini > $dirdest/DataObject.ini;
e=`expr $e + $?`
sed -e "s/$dirace/$dirdeste/g" vardb.sh > $dirdest/vardb.sh
e=`expr $e + $?`

if (test "$e" != "0") then {
	echo "No pudieron modificarse archivos";
	exit 1;
} fi;

cd $dirdest

ln -s sivel.ini $nuevonombd.ini 
ln -s sivel.links.ini $nuevonombd.links.ini

./conf.sh -i
# Crear base 
SIN_ESQUEMA=1 bin/creapg.sh
bin/restaura.sh $rlocal/movido-$nommes.gz

# Cambiar URL
sudo cp /var/www/conf/httpd.conf /var/www/conf/httpd.conf-antesmueve
grep "Alias.*$nuevonombd.*$dirdest" /var/www/conf/httpd.conf 
if (test "$?" != "0") then {
	sudo awk "/Alias.*icons/ { if (agregado != 1) { print \"Alias /$nuevonombd/ \\\"$dirdest/\\\"\"; } agregado=1; } /.*/ { print \$0; }" /var/www/conf/httpd.conf-antesmueve > /tmp/httpd-mueve
	if (test  "$?" != "0") then {
		echo "No pudo agregarse Alias en servidor Apache";
		exit 1;
	} fi;
	sudo cp /tmp/httpd-mueve /var/www/conf/httpd.conf
	sudo apachectl stop
	sleep 1
	sudo sh /etc/rc.local
	echo "";
} fi;

# Comprobar que funciona
grep "^ *FORCE_SSL_PROMPT:yes" /etc/lynx.cfg > /dev/null 2>&1
if (test "$?" != "0") then {
	sudo cp /etc/lynx.cfg /etc/lynx.cfg-antesmueve
	sudo sed -e "s/#* *FORCE_SSL_PROMPT.*/FORCE_SSL_PROMPT:yes/g" /etc/lynx.cfg-antesmueve > /tmp/lynx.cfg-mueve
	sudo cp /tmp/lynx.cfg-mueve /etc/lynx.cfg
} fi;
lynx -dump https://127.0.0.1/$nuevonombd/ > /tmp/dump-mueve
grep "Autenticacin" /tmp/dump-mueve > /dev/null 2>&1
if (test "$?" != "0") then {
	echo "La comprobacin de funcionamiento del nuevo URL fall";
	exit 1;
} fi;

echo "Con un navegador verifique sus datos en https://127.0.0.1/$nuevonombd/";
echo "Si desea borrar las fuentes de su localizacin inicial presione la letra 's'";
read sn
if (test "$sn" = "s") then {
	# Eliminar fuentes anteriores
	sudo pkg_delete sivel
	sudo pkg_delete partial-sivel
	sudo rm -rf $dirac
} fi;
